/***********************************************************************************************************************
* File Name    : mcu_interrupts.c
* Device(s)    : RX
* H/W Platform : GR-SAKURA (RX63N)
* Description  : This module allows for callbacks to be registered for certain interrupts.
***********************************************************************************************************************/
/***********************************************************************************************************************
* History : DD.MM.YYYY Version  Description
*         : 10.07.2017 1.00     First Release
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes   <System Includes> , "Project Includes"
***********************************************************************************************************************/
/* Access to r_bsp. */
#include "platform.h"

/***********************************************************************************************************************
Macro definitions
***********************************************************************************************************************/
/* This macro is used to suppress compiler messages about a parameter not being used in a function. The nice thing
 * about using this implementation is that it does not take any extra RAM or ROM.
 */
#define INTERNAL_NOT_USED(p)        ((void)(p))
/* Let FPSW EV, EO, EZ, EU, EX=1 (FPU exceptions enabled.) */
#define FPU_EXCEPTIONS_ENABLE       (0x00007C00)

/***********************************************************************************************************************
Typedef definitions
***********************************************************************************************************************/

/***********************************************************************************************************************
Exported global variables (to be accessed by other files)
***********************************************************************************************************************/
 
/***********************************************************************************************************************
Private global variables and functions
***********************************************************************************************************************/
/* This array holds callback functions. */
static void (* g_bsp_vectors[BSP_INT_SRC_TOTAL_ITEMS])(void * pdata);

bsp_int_err_t bsp_interrupt_enable_disable(bsp_int_src_t vector, bool enable);

/***********************************************************************************************************************
* Function Name: bsp_interrupt_open
* Description  : Initialize callback function array.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void bsp_interrupt_open (void)
{
    uint32_t i;

    for (i = 0; i < BSP_INT_SRC_TOTAL_ITEMS; i++)
    {
        g_bsp_vectors[i] = FIT_NO_FUNC;
    }
}

/***********************************************************************************************************************
* Function Name: R_BSP_InterruptWrite
* Description  : Registers a callback function for supported interrupts. If FIT_NO_FUNC, NULL, or
*                any other invalid function address is passed for the callback argument then any previously registered
*                callbacks are unregistered. Use of FIT_NO_FUNC is preferred over NULL since access to the address
*                defined by FIT_NO_FUNC will cause a bus error which is easy for the user to catch. NULL typically
*                resolves to 0 which is a valid address on RX MCUs.
* Arguments    : vector -
*                    Which interrupt to register a callback for.
*                callback -
*                    Pointer to function to call when interrupt occurs.
* Return Value : BSP_INT_SUCCESS -
*                    Callback registered
*                BSP_INT_ERR_INVALID_ARG -
*                    Invalid function address input, any previous function has been unregistered
***********************************************************************************************************************/
bsp_int_err_t R_BSP_InterruptWrite (bsp_int_src_t vector,  bsp_int_cb_t callback)
{
    bsp_int_err_t err;

    err = BSP_INT_SUCCESS;

    /* Check for valid address. */
    if (((uint32_t)callback == (uint32_t)NULL) || ((uint32_t)callback == (uint32_t)FIT_NO_FUNC))
    {
        g_bsp_vectors[vector] = FIT_NO_FUNC;
    }
    else
    {
        g_bsp_vectors[vector] = callback;
    }

    return err;
}

/***********************************************************************************************************************
* Function Name: R_BSP_InterruptRead
* Description  : Returns the callback function address for an interrupt.
* Arguments    : vector -
*                    Which interrupt to read the callback for.
*                callback -
*                    Pointer of where to store callback address.
* Return Value : BSP_INT_SUCCESS -
*                    Callback was registered and address has been stored in 'callback' parameter.
*                BSP_INT_ERR_NO_REGISTERED_CALLBACK -
*                    No valid callback has been registered for this interrupt source.
***********************************************************************************************************************/
bsp_int_err_t R_BSP_InterruptRead (bsp_int_src_t vector, bsp_int_cb_t * callback)
{
    bsp_int_err_t err;

    err = BSP_INT_SUCCESS;

    /* Check for valid address. */
    if (((uint32_t)g_bsp_vectors[vector] == (uint32_t)NULL) || ((uint32_t)g_bsp_vectors[vector] == (uint32_t)FIT_NO_FUNC))
    {
        err = BSP_INT_ERR_NO_REGISTERED_CALLBACK;
    }
    else
    {
        *callback = g_bsp_vectors[vector];
    }

    return err;
}

/***********************************************************************************************************************
* Function Name: R_BSP_InterruptControl
* Description  : Executes specified command.
* Arguments    : vector -
*                    Which vector is being used.
*                cmd -
*                    Which command to execute.
*                pdata -
*                    Pointer to data to use with command. Not currently used. Use FIT_NO_PTR.
* Return Value : BSP_INT_SUCCESS -
*                    Command executed successfully.
*                BSP_INT_ERR_NO_REGISTERED_CALLBACK -
*                    No valid callback has been registered for this interrupt source.
*                BSP_INT_ERR_INVALID_ARG -
*                    Invalid command sent in.
***********************************************************************************************************************/
bsp_int_err_t R_BSP_InterruptControl (bsp_int_src_t vector, bsp_int_cmd_t cmd, void * pdata)
{
    bsp_int_err_t       err;
    bsp_int_cb_args_t   cb_args;

    err = BSP_INT_SUCCESS;

    /* This code is only used to remove compiler info messages about these parameters not being used. */
    INTERNAL_NOT_USED(pdata);

    switch (cmd)
    {
        case (BSP_INT_CMD_CALL_CALLBACK):
            if (((uint32_t)g_bsp_vectors[vector] != (uint32_t)NULL) &&
                ((uint32_t)g_bsp_vectors[vector] != (uint32_t)FIT_NO_FUNC))
            {
                /* Fill in callback info. */
                cb_args.vector = vector;

                g_bsp_vectors[vector](&cb_args);
            }
            else
            {
                err = BSP_INT_ERR_NO_REGISTERED_CALLBACK;
            }
        break;

        case (BSP_INT_CMD_INTERRUPT_ENABLE):
            err = bsp_interrupt_enable_disable(vector, true);
        break;

        case (BSP_INT_CMD_INTERRUPT_DISABLE):
            err = bsp_interrupt_enable_disable(vector, false);
        break;

        default:
            err = BSP_INT_ERR_INVALID_ARG;
        break;
    }

    return err;
}

/***********************************************************************************************************************
* Function Name: bsp_interrupt_enable_disable
* Description  : Either enables or disables an interrupt.
* Arguments    : vector -
*                    Which vector to enable or disable.
*                enable -
*                    Whether to enable or disable the interrupt.
* Return Value : BSP_INT_SUCCESS -
*                    Interrupt enabled or disabled.
*                BSP_INT_ERR_UNSUPPORTED -
*                    API does not support enabling/disabling for this vector.
***********************************************************************************************************************/
bsp_int_err_t bsp_interrupt_enable_disable (bsp_int_src_t vector, bool enable)
{
    uint32_t      temp_fpsw;
    bsp_int_err_t err = BSP_INT_SUCCESS;

    switch (vector)
    {
        case (BSP_INT_SRC_BUS_ERROR):

            if (true == enable)
            {
                /* Enable the bus error interrupt to catch accesses to illegal/reserved areas of memory */
                /* Clear any pending interrupts */
                IR(BSC,BUSERR) = 0;
                /* Make this the highest priority interrupt (adjust as necessary for your application */
                IPR(BSC,BUSERR) = 0x0F;
                /* Enable the interrupt in the ICU*/
                IEN(BSC,BUSERR) = 1;
                /* Enable illegal address interrupt in the BSC */
                BSC.BEREN.BIT.IGAEN = 1;
                /* Enable timeout detection enable. */
                BSC.BEREN.BIT.TOEN = 1;
            }
            else
            {
                /* Disable the bus error interrupt. */
                /* Disable the interrupt in the ICU*/
                IEN(BSC,BUSERR) = 0;
                /* Disable illegal address interrupt in the BSC */
                BSC.BEREN.BIT.IGAEN = 0;
                /* Disable timeout detection enable. */
                BSC.BEREN.BIT.TOEN = 0;
            }

        break;

        case (BSP_INT_SRC_EXC_FPU):

            /* Get current FPSW. */
            temp_fpsw = (uint32_t)__builtin_rx_mvfc (0x3);

            if (true == enable)
            {
                /* Set the FPU exception flags. */
                __builtin_rx_mvtc (0x3, temp_fpsw | ((uint32_t)FPU_EXCEPTIONS_ENABLE));
            }
            else
            {
                /* Clear only the FPU exception flags. */
                __builtin_rx_mvtc (0x3, temp_fpsw & ((uint32_t)~FPU_EXCEPTIONS_ENABLE));
            }

        break;

        case (BSP_INT_SRC_EXC_NMI_PIN):

            if (true == enable)
            {
                /* Enable NMI pin interrupt (cannot undo!) */
                ICU.NMIER.BIT.NMIEN = 1;
            }
            else
            {
                /* NMI pin interrupts cannot be disabled after being enabled. */
                err = BSP_INT_ERR_UNSUPPORTED;
            }

        break;

        default:
            err = BSP_INT_ERR_UNSUPPORTED;
        break;
    }

    return err;
}

/* INT_Exception(Access Instruction)*/
void INT_Excep_AccessInst(void)
{
	/* brk(); */
}

/* Dummy*/
void INT_Dummy(void)
{
	/* brk(); */
}

/* BRK*/
void INT_Excep_BRK(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_BRK, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* FCU FIFERR*/
void INT_Excep_FCU_FIFERR(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_FCU_FIFERR, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* FCU FRDYI*/
void INT_Excep_FCU_FRDYI(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_FCU_FRDYI, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU SWINT*/
void INT_Excep_ICU_SWINT(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_ICU_SWINT, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CMT0 CMI0*/
void INT_Excep_CMT0_CMI0(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_CMT0_CMI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CMT1 CMI1*/
void INT_Excep_CMT1_CMI1(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_CMT1_CMI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CMT2 CMI2*/
void INT_Excep_CMT2_CMI2(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_CMT2_CMI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CMT3 CMI3*/
void INT_Excep_CMT3_CMI3(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_CMT3_CMI3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ETHER EINT*/
void INT_Excep_ETHER_EINT(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_ETHER_EINT, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* USB0 D0FIFO0*/
void INT_Excep_USB0_D0FIFO0(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_USB0_D0FIFO0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* USB0 D1FIFO0*/
void INT_Excep_USB0_D1FIFO0(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_USB0_D1FIFO0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* USB0 USBI0*/
void INT_Excep_USB0_USBI0(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_USB0_USBI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* USB1 D0FIFO1*/
void INT_Excep_USB1_D0FIFO1(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_USB1_D0FIFO1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* USB1 D1FIFO1*/
void INT_Excep_USB1_D1FIFO1(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_USB1_D1FIFO1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* USB1 USBI1*/
void INT_Excep_USB1_USBI1(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_USB1_USBI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RSPI0 SPRI0*/
void INT_Excep_RSPI0_SPRI0(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_RSPI0_SPRI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RSPI0 SPTI0*/
void INT_Excep_RSPI0_SPTI0(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_RSPI0_SPTI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RSPI0 SPII0*/
void INT_Excep_RSPI0_SPII0(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_RSPI0_SPII0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RSPI1 SPRI1*/
void INT_Excep_RSPI1_SPRI1(void)
{
	R_BSP_InterruptControl(BSP_INT_SRC_RSPI1_SPRI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RSPI1 SPTI1*/
void INT_Excep_RSPI1_SPTI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RSPI1_SPTI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RSPI1 SPII1*/
void INT_Excep_RSPI1_SPII1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RSPI1_SPII1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RSPI2 SPRI2*/
void INT_Excep_RSPI2_SPRI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RSPI2_SPRI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RSPI2 SPTI2*/
void INT_Excep_RSPI2_SPTI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RSPI2_SPTI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RSPI2 SPII2*/
void INT_Excep_RSPI2_SPII2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RSPI2_SPII2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN0 RXF0*/
void INT_Excep_CAN0_RXF0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN0_RXF0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN0 TXF0*/
void INT_Excep_CAN0_TXF0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN0_TXF0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN0 RXM0*/
void INT_Excep_CAN0_RXM0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN0_RXM0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN0 TXM0*/
void INT_Excep_CAN0_TXM0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN0_TXM0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN1 RXF1*/
void INT_Excep_CAN1_RXF1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN1_RXF1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN1 TXF1*/
void INT_Excep_CAN1_TXF1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN1_TXF1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN1 RXM1*/
void INT_Excep_CAN1_RXM1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN1_RXM1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN1 TXM1*/
void INT_Excep_CAN1_TXM1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN1_TXM1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN2 RXF2*/
void INT_Excep_CAN2_RXF2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN2_RXF2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN2 TXF2*/
void INT_Excep_CAN2_TXF2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN2_TXF2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN2 RXM2*/
void INT_Excep_CAN2_RXM2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN2_RXM2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* CAN2 TXM2*/
void INT_Excep_CAN2_TXM2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_CAN2_TXM2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RTC CUP*/
void INT_Excep_RTC_CUP(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RTC_CUP, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ0*/
void INT_Excep_ICU_IRQ0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ1*/
void INT_Excep_ICU_IRQ1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ2*/
void INT_Excep_ICU_IRQ2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ3*/
void INT_Excep_ICU_IRQ3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ4*/
void INT_Excep_ICU_IRQ4(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ5*/
void INT_Excep_ICU_IRQ5(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ5, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ6*/
void INT_Excep_ICU_IRQ6(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ6, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ7*/
void INT_Excep_ICU_IRQ7(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ7, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ8*/
void INT_Excep_ICU_IRQ8(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ8, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ9*/
void INT_Excep_ICU_IRQ9(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ9, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ10*/
void INT_Excep_ICU_IRQ10(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ10, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ11*/
void INT_Excep_ICU_IRQ11(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ11, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ12*/
void INT_Excep_ICU_IRQ12(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ12, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ13*/
void INT_Excep_ICU_IRQ13(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ13, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ14*/
void INT_Excep_ICU_IRQ14(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ14, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU IRQ15*/
void INT_Excep_ICU_IRQ15(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_IRQ15, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* USB USBR0*/
void INT_Excep_USB_USBR0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_USB_USBR0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* USB USBR1*/
void INT_Excep_USB_USBR1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_USB_USBR1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RTC ALM*/
void INT_Excep_RTC_ALM(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RTC_ALM, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RTC PRD*/
void INT_Excep_RTC_PRD(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RTC_PRD, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* AD ADI0*/
void INT_Excep_AD_ADI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_AD_ADI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* S12AD S12ADI0*/
void INT_Excep_S12AD_S12ADI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_S12AD_S12ADI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU GROUP0*/
void INT_Excep_ICU_GROUP0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_GROUP0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU GROUP1*/
void INT_Excep_ICU_GROUP1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_GROUP1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU GROUP2*/
void INT_Excep_ICU_GROUP2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_GROUP2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU GROUP3*/
void INT_Excep_ICU_GROUP3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_GROUP3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU GROUP4*/
void INT_Excep_ICU_GROUP4(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_GROUP4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU GROUP5*/
void INT_Excep_ICU_GROUP5(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_GROUP5, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU GROUP6*/
void INT_Excep_ICU_GROUP6(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_GROUP6, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* ICU GROUP12*/
void INT_Excep_ICU_GROUP12(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_ICU_GROUP12, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI12 SCIX0*/
void INT_Excep_SCI12_SCIX0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI12_SCIX0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI12 SCIX1*/
void INT_Excep_SCI12_SCIX1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI12_SCIX1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI12 SCIX2*/
void INT_Excep_SCI12_SCIX2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI12_SCIX2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI12 SCIX3*/
void INT_Excep_SCI12_SCIX3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI12_SCIX3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU0 TGI0A*/
void INT_Excep_TPU0_TGI0A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU0_TGI0A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU0 TGI0B*/
void INT_Excep_TPU0_TGI0B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU0_TGI0B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU0 TGI0C*/
void INT_Excep_TPU0_TGI0C(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU0_TGI0C, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU0 TGI0D*/
void INT_Excep_TPU0_TGI0D(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU0_TGI0D, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU1 TGI1A*/
void INT_Excep_TPU1_TGI1A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU1_TGI1A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU1 TGI1B*/
void INT_Excep_TPU1_TGI1B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU1_TGI1B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU2 TGI2A*/
void INT_Excep_TPU2_TGI2A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU2_TGI2A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU2 TGI2B*/
void INT_Excep_TPU2_TGI2B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU2_TGI2B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU3 TGI3A*/
void INT_Excep_TPU3_TGI3A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU3_TGI3A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU3 TGI3B*/
void INT_Excep_TPU3_TGI3B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU3_TGI3B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU3 TGI3C*/
void INT_Excep_TPU3_TGI3C(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU3_TGI3C, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU3 TGI3D*/
void INT_Excep_TPU3_TGI3D(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU3_TGI3D, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU4 TGI4A*/
void INT_Excep_TPU4_TGI4A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU4_TGI4A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU4 TGI4B*/
void INT_Excep_TPU4_TGI4B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU4_TGI4B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU5 TGI5A*/
void INT_Excep_TPU5_TGI5A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU5_TGI5A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU5 TGI5B*/
void INT_Excep_TPU5_TGI5B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU5_TGI5B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU6 TGI6A*/
void INT_Excep_TPU6_TGI6A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU6_TGI6A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU6 TGI6B*/
void INT_Excep_TPU6_TGI6B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU6_TGI6B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU6 TGI6C*/
void INT_Excep_TPU6_TGI6C(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU6_TGI6C, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU6 TGI6D*/
void INT_Excep_TPU6_TGI6D(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU6_TGI6D, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU0 TGIA0*/
void INT_Excep_MTU0_TGIA0(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU0_TGIA0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU0 TGIB0*/
void INT_Excep_MTU0_TGIB0(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU0_TGIB0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU0 TGIC0*/
void INT_Excep_MTU0_TGIC0(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU0_TGIC0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU0 TGID0*/
void INT_Excep_MTU0_TGID0(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU0_TGID0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU0 TGIE0*/
void INT_Excep_MTU0_TGIE0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_MTU0_TGIE0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU0 TGIF0*/
void INT_Excep_MTU0_TGIF0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_MTU0_TGIF0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU7 TGI7A*/
void INT_Excep_TPU7_TGI7A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU7_TGI7A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU7 TGI7B*/
void INT_Excep_TPU7_TGI7B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU7_TGI7B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU1 TGIA1*/
void INT_Excep_MTU1_TGIA1(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU1_TGIA1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU1 TGIB1*/
void INT_Excep_MTU1_TGIB1(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU1_TGIB1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU8 TGI8A*/
void INT_Excep_TPU8_TGI8A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU8_TGI8A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU8 TGI8B*/
void INT_Excep_TPU8_TGI8B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU8_TGI8B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU2 TGIA2*/
void INT_Excep_MTU2_TGIA2(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU2_TGIA2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU2 TGIB2*/
void INT_Excep_MTU2_TGIB2(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU2_TGIB2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU9 TGI9A*/
void INT_Excep_TPU9_TGI9A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU9_TGI9A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU9 TGI9B*/
void INT_Excep_TPU9_TGI9B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU9_TGI9B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU9 TGI9C*/
void INT_Excep_TPU9_TGI9C(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU9_TGI9C, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU9 TGI9D*/
void INT_Excep_TPU9_TGI9D(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU9_TGI9D, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU3 TGIA3*/
void INT_Excep_MTU3_TGIA3(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU3_TGIA3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU3 TGIB3*/
void INT_Excep_MTU3_TGIB3(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU3_TGIB3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU3 TGIC3*/
void INT_Excep_MTU3_TGIC3(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU3_TGIC3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU3 TGID3*/
void INT_Excep_MTU3_TGID3(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU3_TGID3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU10 TGI10A*/
void INT_Excep_TPU10_TGI10A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU10_TGI10A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU10 TGI10B*/
void INT_Excep_TPU10_TGI10B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU10_TGI10B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU4 TGIA4*/
void INT_Excep_MTU4_TGIA4(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU4_TGIA4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU4 TGIB4*/
void INT_Excep_MTU4_TGIB4(void)
{
    //R_BSP_InterruptControl (BSP_INT_SRC_MTU4_TGIB4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU4 TGIC4*/
void INT_Excep_MTU4_TGIC4(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_MTU4_TGIC4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU4 TGID4*/
void INT_Excep_MTU4_TGID4(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_MTU4_TGID4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU4 TCIV4*/
void INT_Excep_MTU4_TCIV4(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_MTU4_TCIV4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU11 TGI11A*/
void INT_Excep_TPU11_TGI11A(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU11_TGI11A, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TPU11 TGI11B*/
void INT_Excep_TPU11_TGI11B(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TPU11_TGI11B, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU5 TGIU5*/
void INT_Excep_MTU5_TGIU5(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_MTU5_TGIU5, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU5 TGIV5*/
void INT_Excep_MTU5_TGIV5(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_MTU5_TGIV5, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* MTU5 TGIW5*/
void INT_Excep_MTU5_TGIW5(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_MTU5_TGIW5, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* POE OEI1*/
void INT_Excep_POE_OEI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_POE_OEI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* POE OEI2*/
void INT_Excep_POE_OEI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_POE_OEI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR0 CMIA0*/
void INT_Excep_TMR0_CMIA0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR0_CMIA0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR0 CMIB0*/
void INT_Excep_TMR0_CMIB0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR0_CMIB0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR0 OVI0*/
void INT_Excep_TMR0_OVI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR0_OVI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR1 CMIA1*/
void INT_Excep_TMR1_CMIA1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR1_CMIA1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR1 CMIB1*/
void INT_Excep_TMR1_CMIB1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR1_CMIB1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR1 OVI1*/
void INT_Excep_TMR1_OVI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR1_OVI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR2 CMIA2*/
void INT_Excep_TMR2_CMIA2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR2_CMIA2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR2 CMIB2*/
void INT_Excep_TMR2_CMIB2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR2_CMIB2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR2 OVI2*/
void INT_Excep_TMR2_OVI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR2_OVI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR3 CMIA3*/
void INT_Excep_TMR3_CMIA3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR3_CMIA3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR3 CMIB3*/
void INT_Excep_TMR3_CMIB3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR3_CMIB3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* TMR3 OVI3*/
void INT_Excep_TMR3_OVI3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_TMR3_OVI3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC0 EEI0*/
void INT_Excep_RIIC0_EEI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC0_EEI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC0 RXI0*/
void INT_Excep_RIIC0_RXI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC0_RXI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC0 TXI0*/
void INT_Excep_RIIC0_TXI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC0_TXI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC0 TEI0*/
void INT_Excep_RIIC0_TEI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC0_TEI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC1 EEI1*/
void INT_Excep_RIIC1_EEI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC1_EEI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC1 RXI1*/
void INT_Excep_RIIC1_RXI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC1_RXI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC1 TXI1*/
void INT_Excep_RIIC1_TXI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC1_TXI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC1 TEI1*/
void INT_Excep_RIIC1_TEI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC1_TEI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC2 EEI2*/
void INT_Excep_RIIC2_EEI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC2_EEI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC2 RXI2*/
void INT_Excep_RIIC2_RXI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC2_RXI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC2 TXI2*/
void INT_Excep_RIIC2_TXI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC2_TXI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC2 TEI2*/
void INT_Excep_RIIC2_TEI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC2_TEI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC3 EEI3*/
void INT_Excep_RIIC3_EEI3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC3_EEI3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC3 RXI3*/
void INT_Excep_RIIC3_RXI3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC3_RXI3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC3 TXI3*/
void INT_Excep_RIIC3_TXI3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC3_TXI3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* RIIC3 TEI3*/
void INT_Excep_RIIC3_TEI3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_RIIC3_TEI3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* DMAC DMAC0I*/
void INT_Excep_DMAC_DMAC0I(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_DMAC_DMAC0I, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* DMAC DMAC1I*/
void INT_Excep_DMAC_DMAC1I(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_DMAC_DMAC1I, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* DMAC DMAC2I*/
void INT_Excep_DMAC_DMAC2I(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_DMAC_DMAC2I, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* DMAC DMAC3I*/
void INT_Excep_DMAC_DMAC3I(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_DMAC_DMAC3I, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* EXDMAC EXDMAC0I*/
void INT_Excep_EXDMAC_EXDMAC0I(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_EXDMAC_EXDMAC0I, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* EXDMAC EXDMAC1I*/
void INT_Excep_EXDMAC_EXDMAC1I(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_EXDMAC_EXDMAC1I, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* DEU DEU0*/
void INT_Excep_DEU_DEU0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_DEU_DEU0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* DEU DEU1*/
void INT_Excep_DEU_DEU1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_DEU_DEU1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* PDC PCDFI*/
void INT_Excep_PDC_PCDFI(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_PDC_PCDFI, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* PDC PCFEI*/
void INT_Excep_PDC_PCFEI(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_PDC_PCFEI, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* PDC PCERI*/
void INT_Excep_PDC_PCERI(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_PDC_PCERI, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI0 RXI0*/
void INT_Excep_SCI0_RXI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI0_RXI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI0 TXI0*/
void INT_Excep_SCI0_TXI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI0_TXI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI0 TEI0*/
void INT_Excep_SCI0_TEI0(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI0_TEI0, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI1 RXI1*/
void INT_Excep_SCI1_RXI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI1_RXI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI1 TXI1*/
void INT_Excep_SCI1_TXI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI1_TXI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI1 TEI1*/
void INT_Excep_SCI1_TEI1(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI1_TEI1, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI2 RXI2*/
void INT_Excep_SCI2_RXI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI2_RXI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI2 TXI2*/
void INT_Excep_SCI2_TXI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI2_TXI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI2 TEI2*/
void INT_Excep_SCI2_TEI2(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI2_TEI2, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI3 RXI3*/
void INT_Excep_SCI3_RXI3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI3_RXI3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI3 TXI3*/
void INT_Excep_SCI3_TXI3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI3_TXI3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI3 TEI3*/
void INT_Excep_SCI3_TEI3(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI3_TEI3, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI4 RXI4*/
void INT_Excep_SCI4_RXI4(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI4_RXI4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI4 TXI4*/
void INT_Excep_SCI4_TXI4(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI4_TXI4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI4 TEI4*/
void INT_Excep_SCI4_TEI4(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI4_TEI4, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI5 RXI5*/
void INT_Excep_SCI5_RXI5(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI5_RXI5, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI5 TXI5*/
void INT_Excep_SCI5_TXI5(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI5_TXI5, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI5 TEI5*/
void INT_Excep_SCI5_TEI5(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI5_TEI5, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI6 RXI6*/
void INT_Excep_SCI6_RXI6(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI6_RXI6, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI6 TXI6*/
void INT_Excep_SCI6_TXI6(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI6_TXI6, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI6 TEI6*/
void INT_Excep_SCI6_TEI6(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI6_TEI6, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI7 RXI7*/
void INT_Excep_SCI7_RXI7(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI7_RXI7, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI7 TXI7*/
void INT_Excep_SCI7_TXI7(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI7_TXI7, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI7 TEI7*/
void INT_Excep_SCI7_TEI7(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI7_TEI7, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI8 RXI8*/
void INT_Excep_SCI8_RXI8(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI8_RXI8, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI8 TXI8*/
void INT_Excep_SCI8_TXI8(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI8_TXI8, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI8 TEI8*/
void INT_Excep_SCI8_TEI8(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI8_TEI8, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI9 RXI9*/
void INT_Excep_SCI9_RXI9(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI9_RXI9, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI9 TXI9*/
void INT_Excep_SCI9_TXI9(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI9_TXI9, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI9 TEI9*/
void INT_Excep_SCI9_TEI9(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI9_TEI9, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI10 RXI10*/
void INT_Excep_SCI10_RXI10(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI10_RXI10, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI10 TXI10*/
void INT_Excep_SCI10_TXI10(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI10_TXI10, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI10 TEI10*/
void INT_Excep_SCI10_TEI10(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI10_TEI10, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI11 RXI11*/
void INT_Excep_SCI11_RXI11(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI11_RXI11, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI11 TXI11*/
void INT_Excep_SCI11_TXI11(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI11_TXI11, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI11 TEI11*/
void INT_Excep_SCI11_TEI11(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI11_TEI11, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI12 RXI12*/
void INT_Excep_SCI12_RXI12(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI12_RXI12, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI12 TXI12*/
void INT_Excep_SCI12_TXI12(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI12_TXI12, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* SCI12 TEI12*/
void INT_Excep_SCI12_TEI12(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_SCI12_TEI12, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

/* IEB IEBINT*/
void INT_Excep_IEB_IEBINT(void)
{
    R_BSP_InterruptControl (BSP_INT_SRC_IEB_IEBINT, BSP_INT_CMD_CALL_CALLBACK, FIT_NO_PTR);
}

