/***********************************************************************************************************************
* File Name    : mcu_interrupts.c
* Device(s)    : RX
* H/W Platform : GR-SAKURA (RX63N)
* Description  : This module allows for callbacks to be registered for certain interrupts.
***********************************************************************************************************************/
/***********************************************************************************************************************
* History : DD.MM.YYYY Version  Description
*         : 10.07.2017 1.00     First Release
***********************************************************************************************************************/

/***********************************************************************************************************************
Macro definitions
***********************************************************************************************************************/

/***********************************************************************************************************************
Typedef definitions
***********************************************************************************************************************/
/* Available return codes. */
typedef enum
{
    BSP_INT_SUCCESS = 0,
    BSP_INT_ERR_NO_REGISTERED_CALLBACK,     //There is not a registered callback for this interrupt source
    BSP_INT_ERR_INVALID_ARG,                //Illegal argument input
    BSP_INT_ERR_UNSUPPORTED                 //Operation is not supported by this API
} bsp_int_err_t;

/* Available interrupts to register a callback for. */
typedef enum
{
    BSP_INT_SRC_EXC_SUPERVISOR_INSTR = 0, //Occurs when privileged instruction is executed in User Mode
    BSP_INT_SRC_EXC_UNDEFINED_INSTR,      //Occurs when MCU encounters an unknown instruction
    BSP_INT_SRC_EXC_NMI_PIN,              //NMI Pin interrupt
    BSP_INT_SRC_EXC_FPU,                  //FPU exception
    BSP_INT_SRC_OSC_STOP_DETECT,          //Oscillation stop is detected
    BSP_INT_SRC_WDT_ERROR,                //WDT underflow/refresh error has occurred
    BSP_INT_SRC_IWDT_ERROR,               //IWDT underflow/refresh error has occurred
    BSP_INT_SRC_LVD1,                     //Voltage monitoring 1 interrupt
    BSP_INT_SRC_LVD2,                     //Voltage monitoring 2 interrupt
    BSP_INT_SRC_UNDEFINED_INTERRUPT,      //Interrupt has triggered for a vector that user did not write a handler for
    BSP_INT_SRC_BUS_ERROR,                //Bus error: illegal address access or timeout
	BSP_INT_SRC_BRK,
	BSP_INT_SRC_FCU_FIFERR,
	BSP_INT_SRC_FCU_FRDYI,
	BSP_INT_SRC_ICU_SWINT,
	BSP_INT_SRC_CMT0_CMI0,
	BSP_INT_SRC_CMT1_CMI1,
	BSP_INT_SRC_CMT2_CMI2,
	BSP_INT_SRC_CMT3_CMI3,
	BSP_INT_SRC_ETHER_EINT,
	BSP_INT_SRC_USB0_D0FIFO0,
	BSP_INT_SRC_USB0_D1FIFO0,
	BSP_INT_SRC_USB0_USBI0,
	BSP_INT_SRC_USB1_D0FIFO1,
	BSP_INT_SRC_USB1_D1FIFO1,
	BSP_INT_SRC_USB1_USBI1,
	BSP_INT_SRC_RSPI0_SPRI0,
	BSP_INT_SRC_RSPI0_SPTI0,
	BSP_INT_SRC_RSPI0_SPII0,
	BSP_INT_SRC_RSPI1_SPRI1,
	BSP_INT_SRC_RSPI1_SPTI1,
	BSP_INT_SRC_RSPI1_SPII1,
	BSP_INT_SRC_RSPI2_SPRI2,
	BSP_INT_SRC_RSPI2_SPTI2,
	BSP_INT_SRC_RSPI2_SPII2,
	BSP_INT_SRC_CAN0_RXF0,
	BSP_INT_SRC_CAN0_TXF0,
	BSP_INT_SRC_CAN0_RXM0,
	BSP_INT_SRC_CAN0_TXM0,
	BSP_INT_SRC_CAN1_RXF1,
	BSP_INT_SRC_CAN1_TXF1,
	BSP_INT_SRC_CAN1_RXM1,
	BSP_INT_SRC_CAN1_TXM1,
	BSP_INT_SRC_CAN2_RXF2,
	BSP_INT_SRC_CAN2_TXF2,
	BSP_INT_SRC_CAN2_RXM2,
	BSP_INT_SRC_CAN2_TXM2,
	BSP_INT_SRC_RTC_CUP,
	BSP_INT_SRC_ICU_IRQ0,
	BSP_INT_SRC_ICU_IRQ1,
	BSP_INT_SRC_ICU_IRQ2,
	BSP_INT_SRC_ICU_IRQ3,
	BSP_INT_SRC_ICU_IRQ4,
	BSP_INT_SRC_ICU_IRQ5,
	BSP_INT_SRC_ICU_IRQ6,
	BSP_INT_SRC_ICU_IRQ7,
	BSP_INT_SRC_ICU_IRQ8,
	BSP_INT_SRC_ICU_IRQ9,
	BSP_INT_SRC_ICU_IRQ10,
	BSP_INT_SRC_ICU_IRQ11,
	BSP_INT_SRC_ICU_IRQ12,
	BSP_INT_SRC_ICU_IRQ13,
	BSP_INT_SRC_ICU_IRQ14,
	BSP_INT_SRC_ICU_IRQ15,
	BSP_INT_SRC_USB_USBR0,
	BSP_INT_SRC_USB_USBR1,
	BSP_INT_SRC_RTC_ALM,
	BSP_INT_SRC_RTC_PRD,
	BSP_INT_SRC_AD_ADI0,
	BSP_INT_SRC_S12AD_S12ADI0,
	BSP_INT_SRC_ICU_GROUP0,
	BSP_INT_SRC_ICU_GROUP1,
	BSP_INT_SRC_ICU_GROUP2,
	BSP_INT_SRC_ICU_GROUP3,
	BSP_INT_SRC_ICU_GROUP4,
	BSP_INT_SRC_ICU_GROUP5,
	BSP_INT_SRC_ICU_GROUP6,
	BSP_INT_SRC_ICU_GROUP12,
	BSP_INT_SRC_SCI12_SCIX0,
	BSP_INT_SRC_SCI12_SCIX1,
	BSP_INT_SRC_SCI12_SCIX2,
	BSP_INT_SRC_SCI12_SCIX3,
	BSP_INT_SRC_TPU0_TGI0A,
	BSP_INT_SRC_TPU0_TGI0B,
	BSP_INT_SRC_TPU0_TGI0C,
	BSP_INT_SRC_TPU0_TGI0D,
	BSP_INT_SRC_TPU1_TGI1A,
	BSP_INT_SRC_TPU1_TGI1B,
	BSP_INT_SRC_TPU2_TGI2A,
	BSP_INT_SRC_TPU2_TGI2B,
	BSP_INT_SRC_TPU3_TGI3A,
	BSP_INT_SRC_TPU3_TGI3B,
	BSP_INT_SRC_TPU3_TGI3C,
	BSP_INT_SRC_TPU3_TGI3D,
	BSP_INT_SRC_TPU4_TGI4A,
	BSP_INT_SRC_TPU4_TGI4B,
	BSP_INT_SRC_TPU5_TGI5A,
	BSP_INT_SRC_TPU5_TGI5B,
	BSP_INT_SRC_TPU6_TGI6A,
	//BSP_INT_SRC_MTU0_TGIA0,
	BSP_INT_SRC_TPU6_TGI6B,
	//BSP_INT_SRC_MTU0_TGIB0,
	BSP_INT_SRC_TPU6_TGI6C,
	//BSP_INT_SRC_MTU0_TGIC0,
	BSP_INT_SRC_TPU6_TGI6D,
	//BSP_INT_SRC_MTU0_TGID0,
	BSP_INT_SRC_MTU0_TGIE0,
	BSP_INT_SRC_MTU0_TGIF0,
	BSP_INT_SRC_TPU7_TGI7A,
	//BSP_INT_SRC_MTU1_TGIA1,
	BSP_INT_SRC_TPU7_TGI7B,
	//BSP_INT_SRC_MTU1_TGIB1,
	BSP_INT_SRC_TPU8_TGI8A,
	//BSP_INT_SRC_MTU2_TGIA2,
	BSP_INT_SRC_TPU8_TGI8B,
	//BSP_INT_SRC_MTU2_TGIB2,
	BSP_INT_SRC_TPU9_TGI9A,
	//BSP_INT_SRC_MTU3_TGIA3,
	BSP_INT_SRC_TPU9_TGI9B,
	//BSP_INT_SRC_MTU3_TGIB3,
	BSP_INT_SRC_TPU9_TGI9C,
	//BSP_INT_SRC_MTU3_TGIC3,
	BSP_INT_SRC_TPU9_TGI9D,
	//BSP_INT_SRC_MTU3_TGID3,
	BSP_INT_SRC_TPU10_TGI10A,
	//BSP_INT_SRC_MTU4_TGIA4,
	BSP_INT_SRC_TPU10_TGI10B,
	//BSP_INT_SRC_MTU4_TGIB4,
	BSP_INT_SRC_MTU4_TGIC4,
	BSP_INT_SRC_MTU4_TGID4,
	BSP_INT_SRC_MTU4_TCIV4,
	BSP_INT_SRC_MTU5_TGIU5,
	BSP_INT_SRC_MTU5_TGIV5,
	BSP_INT_SRC_MTU5_TGIW5,
	BSP_INT_SRC_TPU11_TGI11A,
	BSP_INT_SRC_TPU11_TGI11B,
	BSP_INT_SRC_POE_OEI1,
	BSP_INT_SRC_POE_OEI2,
	BSP_INT_SRC_TMR0_CMIA0,
	BSP_INT_SRC_TMR0_CMIB0,
	BSP_INT_SRC_TMR0_OVI0,
	BSP_INT_SRC_TMR1_CMIA1,
	BSP_INT_SRC_TMR1_CMIB1,
	BSP_INT_SRC_TMR1_OVI1,
	BSP_INT_SRC_TMR2_CMIA2,
	BSP_INT_SRC_TMR2_CMIB2,
	BSP_INT_SRC_TMR2_OVI2,
	BSP_INT_SRC_TMR3_CMIA3,
	BSP_INT_SRC_TMR3_CMIB3,
	BSP_INT_SRC_TMR3_OVI3,
	BSP_INT_SRC_RIIC0_EEI0,
	BSP_INT_SRC_RIIC0_RXI0,
	BSP_INT_SRC_RIIC0_TXI0,
	BSP_INT_SRC_RIIC0_TEI0,
	BSP_INT_SRC_RIIC1_EEI1,
	BSP_INT_SRC_RIIC1_RXI1,
	BSP_INT_SRC_RIIC1_TXI1,
	BSP_INT_SRC_RIIC1_TEI1,
	BSP_INT_SRC_RIIC2_EEI2,
	BSP_INT_SRC_RIIC2_RXI2,
	BSP_INT_SRC_RIIC2_TXI2,
	BSP_INT_SRC_RIIC2_TEI2,
	BSP_INT_SRC_RIIC3_EEI3,
	BSP_INT_SRC_RIIC3_RXI3,
	BSP_INT_SRC_RIIC3_TXI3,
	BSP_INT_SRC_RIIC3_TEI3,
	BSP_INT_SRC_DMAC_DMAC0I,
	BSP_INT_SRC_DMAC_DMAC1I,
	BSP_INT_SRC_DMAC_DMAC2I,
	BSP_INT_SRC_DMAC_DMAC3I,
	BSP_INT_SRC_EXDMAC_EXDMAC0I,
	BSP_INT_SRC_EXDMAC_EXDMAC1I,
	BSP_INT_SRC_DEU_DEU0,
	BSP_INT_SRC_DEU_DEU1,
	BSP_INT_SRC_PDC_PCDFI,
	BSP_INT_SRC_PDC_PCFEI,
	BSP_INT_SRC_PDC_PCERI,
	BSP_INT_SRC_SCI0_RXI0,
	BSP_INT_SRC_SCI0_TXI0,
	BSP_INT_SRC_SCI0_TEI0,
	BSP_INT_SRC_SCI1_RXI1,
	BSP_INT_SRC_SCI1_TXI1,
	BSP_INT_SRC_SCI1_TEI1,
	BSP_INT_SRC_SCI2_RXI2,
	BSP_INT_SRC_SCI2_TXI2,
	BSP_INT_SRC_SCI2_TEI2,
	BSP_INT_SRC_SCI3_RXI3,
	BSP_INT_SRC_SCI3_TXI3,
	BSP_INT_SRC_SCI3_TEI3,
	BSP_INT_SRC_SCI4_RXI4,
	BSP_INT_SRC_SCI4_TXI4,
	BSP_INT_SRC_SCI4_TEI4,
	BSP_INT_SRC_SCI5_RXI5,
	BSP_INT_SRC_SCI5_TXI5,
	BSP_INT_SRC_SCI5_TEI5,
	BSP_INT_SRC_SCI6_RXI6,
	BSP_INT_SRC_SCI6_TXI6,
	BSP_INT_SRC_SCI6_TEI6,
	BSP_INT_SRC_SCI7_RXI7,
	BSP_INT_SRC_SCI7_TXI7,
	BSP_INT_SRC_SCI7_TEI7,
	BSP_INT_SRC_SCI8_RXI8,
	BSP_INT_SRC_SCI8_TXI8,
	BSP_INT_SRC_SCI8_TEI8,
	BSP_INT_SRC_SCI9_RXI9,
	BSP_INT_SRC_SCI9_TXI9,
	BSP_INT_SRC_SCI9_TEI9,
	BSP_INT_SRC_SCI10_RXI10,
	BSP_INT_SRC_SCI10_TXI10,
	BSP_INT_SRC_SCI10_TEI10,
	BSP_INT_SRC_SCI11_RXI11,
	BSP_INT_SRC_SCI11_TXI11,
	BSP_INT_SRC_SCI11_TEI11,
	BSP_INT_SRC_SCI12_RXI12,
	BSP_INT_SRC_SCI12_TXI12,
	BSP_INT_SRC_SCI12_TEI12,
	BSP_INT_SRC_IEB_IEBINT,
    BSP_INT_SRC_TOTAL_ITEMS               //DO NOT MODIFY! This is used for sizing the interrupt callback array.
} bsp_int_src_t;

/* Available commands for R_BSP_InterruptControl() function. */
typedef enum
{
    BSP_INT_CMD_CALL_CALLBACK = 0,        //Calls registered callback function if one exists
    BSP_INT_CMD_INTERRUPT_ENABLE,         //Enables a given interrupt (Available for NMI pin, FPU, and Bus Error)
    BSP_INT_CMD_INTERRUPT_DISABLE         //Disables a given interrupt (Available for FPU, and Bus Error)
} bsp_int_cmd_t;

/* Easy to use typedef for callback functions. */
typedef void (*bsp_int_cb_t)(void *);

/* This structure is the common one that is passed as the 'void *' argument to callback functions when an
 * exception occurs.
 */
typedef struct
{
    bsp_int_src_t vector;         //Which vector caused this interrupt
} bsp_int_cb_args_t;

/***********************************************************************************************************************
Exported global variables
***********************************************************************************************************************/

/***********************************************************************************************************************
Exported global functions (to be accessed by other files)
***********************************************************************************************************************/
bsp_int_err_t R_BSP_InterruptWrite(bsp_int_src_t vector,  bsp_int_cb_t callback);
bsp_int_err_t R_BSP_InterruptRead(bsp_int_src_t vector, bsp_int_cb_t * callback);
bsp_int_err_t R_BSP_InterruptControl(bsp_int_src_t vector, bsp_int_cmd_t cmd, void * pdata);

void bsp_interrupt_open(void); //r_bsp internal function. DO NOT CALL.

void INT_Excep_AccessInst(void) __attribute__ ((interrupt));
void INT_Dummy(void) __attribute__ ((interrupt));
void INT_Excep_BRK(void) __attribute__ ((interrupt));
void INT_Excep_FCU_FIFERR(void) __attribute__ ((interrupt));
void INT_Excep_FCU_FRDYI(void) __attribute__ ((interrupt));
void INT_Excep_ICU_SWINT(void) __attribute__ ((interrupt));
void INT_Excep_CMT0_CMI0(void) __attribute__ ((interrupt));
void INT_Excep_CMT1_CMI1(void) __attribute__ ((interrupt));
void INT_Excep_CMT2_CMI2(void) __attribute__ ((interrupt));
void INT_Excep_CMT3_CMI3(void) __attribute__ ((interrupt));
void INT_Excep_ETHER_EINT(void) __attribute__ ((interrupt));
void INT_Excep_USB0_D0FIFO0(void) __attribute__ ((interrupt));
void INT_Excep_USB0_D1FIFO0(void) __attribute__ ((interrupt));
void INT_Excep_USB0_USBI0(void) __attribute__ ((interrupt));
void INT_Excep_USB1_D0FIFO1(void) __attribute__ ((interrupt));
void INT_Excep_USB1_D1FIFO1(void) __attribute__ ((interrupt));
void INT_Excep_USB1_USBI1(void) __attribute__ ((interrupt));
void INT_Excep_RSPI0_SPRI0(void) __attribute__ ((interrupt));
void INT_Excep_RSPI0_SPTI0(void) __attribute__ ((interrupt));
void INT_Excep_RSPI0_SPII0(void) __attribute__ ((interrupt));
void INT_Excep_RSPI1_SPRI1(void) __attribute__ ((interrupt));
void INT_Excep_RSPI1_SPTI1(void) __attribute__ ((interrupt));
void INT_Excep_RSPI1_SPII1(void) __attribute__ ((interrupt));
void INT_Excep_RSPI2_SPRI2(void) __attribute__ ((interrupt));
void INT_Excep_RSPI2_SPTI2(void) __attribute__ ((interrupt));
void INT_Excep_RSPI2_SPII2(void) __attribute__ ((interrupt));
void INT_Excep_CAN0_RXF0(void) __attribute__ ((interrupt));
void INT_Excep_CAN0_TXF0(void) __attribute__ ((interrupt));
void INT_Excep_CAN0_RXM0(void) __attribute__ ((interrupt));
void INT_Excep_CAN0_TXM0(void) __attribute__ ((interrupt));
void INT_Excep_CAN1_RXF1(void) __attribute__ ((interrupt));
void INT_Excep_CAN1_TXF1(void) __attribute__ ((interrupt));
void INT_Excep_CAN1_RXM1(void) __attribute__ ((interrupt));
void INT_Excep_CAN1_TXM1(void) __attribute__ ((interrupt));
void INT_Excep_CAN2_RXF2(void) __attribute__ ((interrupt));
void INT_Excep_CAN2_TXF2(void) __attribute__ ((interrupt));
void INT_Excep_CAN2_RXM2(void) __attribute__ ((interrupt));
void INT_Excep_CAN2_TXM2(void) __attribute__ ((interrupt));
void INT_Excep_RTC_CUP(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ0(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ1(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ2(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ3(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ4(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ5(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ6(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ7(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ8(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ9(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ10(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ11(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ12(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ13(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ14(void) __attribute__ ((interrupt));
void INT_Excep_ICU_IRQ15(void) __attribute__ ((interrupt));
void INT_Excep_USB_USBR0(void) __attribute__ ((interrupt));
void INT_Excep_USB_USBR1(void) __attribute__ ((interrupt));
void INT_Excep_RTC_ALM(void) __attribute__ ((interrupt));
void INT_Excep_RTC_PRD(void) __attribute__ ((interrupt));
void INT_Excep_AD_ADI0(void) __attribute__ ((interrupt));
void INT_Excep_S12AD_S12ADI0(void) __attribute__ ((interrupt));
void INT_Excep_ICU_GROUP0(void) __attribute__ ((interrupt));
void INT_Excep_ICU_GROUP1(void) __attribute__ ((interrupt));
void INT_Excep_ICU_GROUP2(void) __attribute__ ((interrupt));
void INT_Excep_ICU_GROUP3(void) __attribute__ ((interrupt));
void INT_Excep_ICU_GROUP4(void) __attribute__ ((interrupt));
void INT_Excep_ICU_GROUP5(void) __attribute__ ((interrupt));
void INT_Excep_ICU_GROUP6(void) __attribute__ ((interrupt));
void INT_Excep_ICU_GROUP12(void) __attribute__ ((interrupt));
void INT_Excep_SCI12_SCIX0(void) __attribute__ ((interrupt));
void INT_Excep_SCI12_SCIX1(void) __attribute__ ((interrupt));
void INT_Excep_SCI12_SCIX2(void) __attribute__ ((interrupt));
void INT_Excep_SCI12_SCIX3(void) __attribute__ ((interrupt));
void INT_Excep_TPU0_TGI0A(void) __attribute__ ((interrupt));
void INT_Excep_TPU0_TGI0B(void) __attribute__ ((interrupt));
void INT_Excep_TPU0_TGI0C(void) __attribute__ ((interrupt));
void INT_Excep_TPU0_TGI0D(void) __attribute__ ((interrupt));
void INT_Excep_TPU1_TGI1A(void) __attribute__ ((interrupt));
void INT_Excep_TPU1_TGI1B(void) __attribute__ ((interrupt));
void INT_Excep_TPU2_TGI2A(void) __attribute__ ((interrupt));
void INT_Excep_TPU2_TGI2B(void) __attribute__ ((interrupt));
void INT_Excep_TPU3_TGI3A(void) __attribute__ ((interrupt));
void INT_Excep_TPU3_TGI3B(void) __attribute__ ((interrupt));
void INT_Excep_TPU3_TGI3C(void) __attribute__ ((interrupt));
void INT_Excep_TPU3_TGI3D(void) __attribute__ ((interrupt));
void INT_Excep_TPU4_TGI4A(void) __attribute__ ((interrupt));
void INT_Excep_TPU4_TGI4B(void) __attribute__ ((interrupt));
void INT_Excep_TPU5_TGI5A(void) __attribute__ ((interrupt));
void INT_Excep_TPU5_TGI5B(void) __attribute__ ((interrupt));
void INT_Excep_TPU6_TGI6A(void) __attribute__ ((interrupt));
//void INT_Excep_MTU0_TGIA0(void) __attribute__ ((interrupt));
void INT_Excep_TPU6_TGI6B(void) __attribute__ ((interrupt));
//void INT_Excep_MTU0_TGIB0(void) __attribute__ ((interrupt));
void INT_Excep_TPU6_TGI6C(void) __attribute__ ((interrupt));
//void INT_Excep_MTU0_TGIC0(void) __attribute__ ((interrupt));
void INT_Excep_TPU6_TGI6D(void) __attribute__ ((interrupt));
//void INT_Excep_MTU0_TGID0(void) __attribute__ ((interrupt));
void INT_Excep_MTU0_TGIE0(void) __attribute__ ((interrupt));
void INT_Excep_MTU0_TGIF0(void) __attribute__ ((interrupt));
void INT_Excep_TPU7_TGI7A(void) __attribute__ ((interrupt));
//void INT_Excep_MTU1_TGIA1(void) __attribute__ ((interrupt));
void INT_Excep_TPU7_TGI7B(void) __attribute__ ((interrupt));
//void INT_Excep_MTU1_TGIB1(void) __attribute__ ((interrupt));
void INT_Excep_TPU8_TGI8A(void) __attribute__ ((interrupt));
//void INT_Excep_MTU2_TGIA2(void) __attribute__ ((interrupt));
void INT_Excep_TPU8_TGI8B(void) __attribute__ ((interrupt));
//void INT_Excep_MTU2_TGIB2(void) __attribute__ ((interrupt));
void INT_Excep_TPU9_TGI9A(void) __attribute__ ((interrupt));
//void INT_Excep_MTU3_TGIA3(void) __attribute__ ((interrupt));
void INT_Excep_TPU9_TGI9B(void) __attribute__ ((interrupt));
//void INT_Excep_MTU3_TGIB3(void) __attribute__ ((interrupt));
void INT_Excep_TPU9_TGI9C(void) __attribute__ ((interrupt));
//void INT_Excep_MTU3_TGIC3(void) __attribute__ ((interrupt));
void INT_Excep_TPU9_TGI9D(void) __attribute__ ((interrupt));
//void INT_Excep_MTU3_TGID3(void) __attribute__ ((interrupt));
void INT_Excep_TPU10_TGI10A(void) __attribute__ ((interrupt));
//void INT_Excep_MTU4_TGIA4(void) __attribute__ ((interrupt));
void INT_Excep_TPU10_TGI10B(void) __attribute__ ((interrupt));
//void INT_Excep_MTU4_TGIB4(void) __attribute__ ((interrupt));
void INT_Excep_MTU4_TGIC4(void) __attribute__ ((interrupt));
void INT_Excep_MTU4_TGID4(void) __attribute__ ((interrupt));
void INT_Excep_MTU4_TCIV4(void) __attribute__ ((interrupt));
void INT_Excep_MTU5_TGIU5(void) __attribute__ ((interrupt));
void INT_Excep_MTU5_TGIV5(void) __attribute__ ((interrupt));
void INT_Excep_MTU5_TGIW5(void) __attribute__ ((interrupt));
void INT_Excep_TPU11_TGI11A(void) __attribute__ ((interrupt));
void INT_Excep_TPU11_TGI11B(void) __attribute__ ((interrupt));
void INT_Excep_POE_OEI1(void) __attribute__ ((interrupt));
void INT_Excep_POE_OEI2(void) __attribute__ ((interrupt));
void INT_Excep_TMR0_CMIA0(void) __attribute__ ((interrupt));
void INT_Excep_TMR0_CMIB0(void) __attribute__ ((interrupt));
void INT_Excep_TMR0_OVI0(void) __attribute__ ((interrupt));
void INT_Excep_TMR1_CMIA1(void) __attribute__ ((interrupt));
void INT_Excep_TMR1_CMIB1(void) __attribute__ ((interrupt));
void INT_Excep_TMR1_OVI1(void) __attribute__ ((interrupt));
void INT_Excep_TMR2_CMIA2(void) __attribute__ ((interrupt));
void INT_Excep_TMR2_CMIB2(void) __attribute__ ((interrupt));
void INT_Excep_TMR2_OVI2(void) __attribute__ ((interrupt));
void INT_Excep_TMR3_CMIA3(void) __attribute__ ((interrupt));
void INT_Excep_TMR3_CMIB3(void) __attribute__ ((interrupt));
void INT_Excep_TMR3_OVI3(void) __attribute__ ((interrupt));
void INT_Excep_RIIC0_EEI0(void) __attribute__ ((interrupt));
void INT_Excep_RIIC0_RXI0(void) __attribute__ ((interrupt));
void INT_Excep_RIIC0_TXI0(void) __attribute__ ((interrupt));
void INT_Excep_RIIC0_TEI0(void) __attribute__ ((interrupt));
void INT_Excep_RIIC1_EEI1(void) __attribute__ ((interrupt));
void INT_Excep_RIIC1_RXI1(void) __attribute__ ((interrupt));
void INT_Excep_RIIC1_TXI1(void) __attribute__ ((interrupt));
void INT_Excep_RIIC1_TEI1(void) __attribute__ ((interrupt));
void INT_Excep_RIIC2_EEI2(void) __attribute__ ((interrupt));
void INT_Excep_RIIC2_RXI2(void) __attribute__ ((interrupt));
void INT_Excep_RIIC2_TXI2(void) __attribute__ ((interrupt));
void INT_Excep_RIIC2_TEI2(void) __attribute__ ((interrupt));
void INT_Excep_RIIC3_EEI3(void) __attribute__ ((interrupt));
void INT_Excep_RIIC3_RXI3(void) __attribute__ ((interrupt));
void INT_Excep_RIIC3_TXI3(void) __attribute__ ((interrupt));
void INT_Excep_RIIC3_TEI3(void) __attribute__ ((interrupt));
void INT_Excep_DMAC_DMAC0I(void) __attribute__ ((interrupt));
void INT_Excep_DMAC_DMAC1I(void) __attribute__ ((interrupt));
void INT_Excep_DMAC_DMAC2I(void) __attribute__ ((interrupt));
void INT_Excep_DMAC_DMAC3I(void) __attribute__ ((interrupt));
void INT_Excep_EXDMAC_EXDMAC0I(void) __attribute__ ((interrupt));
void INT_Excep_EXDMAC_EXDMAC1I(void) __attribute__ ((interrupt));
void INT_Excep_DEU_DEU0(void) __attribute__ ((interrupt));
void INT_Excep_DEU_DEU1(void) __attribute__ ((interrupt));
void INT_Excep_PDC_PCDFI(void) __attribute__ ((interrupt));
void INT_Excep_PDC_PCFEI(void) __attribute__ ((interrupt));
void INT_Excep_PDC_PCERI(void) __attribute__ ((interrupt));
void INT_Excep_SCI0_RXI0(void) __attribute__ ((interrupt));
void INT_Excep_SCI0_TXI0(void) __attribute__ ((interrupt));
void INT_Excep_SCI0_TEI0(void) __attribute__ ((interrupt));
void INT_Excep_SCI1_RXI1(void) __attribute__ ((interrupt));
void INT_Excep_SCI1_TXI1(void) __attribute__ ((interrupt));
void INT_Excep_SCI1_TEI1(void) __attribute__ ((interrupt));
void INT_Excep_SCI2_RXI2(void) __attribute__ ((interrupt));
void INT_Excep_SCI2_TXI2(void) __attribute__ ((interrupt));
void INT_Excep_SCI2_TEI2(void) __attribute__ ((interrupt));
void INT_Excep_SCI3_RXI3(void) __attribute__ ((interrupt));
void INT_Excep_SCI3_TXI3(void) __attribute__ ((interrupt));
void INT_Excep_SCI3_TEI3(void) __attribute__ ((interrupt));
void INT_Excep_SCI4_RXI4(void) __attribute__ ((interrupt));
void INT_Excep_SCI4_TXI4(void) __attribute__ ((interrupt));
void INT_Excep_SCI4_TEI4(void) __attribute__ ((interrupt));
void INT_Excep_SCI5_RXI5(void) __attribute__ ((interrupt));
void INT_Excep_SCI5_TXI5(void) __attribute__ ((interrupt));
void INT_Excep_SCI5_TEI5(void) __attribute__ ((interrupt));
void INT_Excep_SCI6_RXI6(void) __attribute__ ((interrupt));
void INT_Excep_SCI6_TXI6(void) __attribute__ ((interrupt));
void INT_Excep_SCI6_TEI6(void) __attribute__ ((interrupt));
void INT_Excep_SCI7_RXI7(void) __attribute__ ((interrupt));
void INT_Excep_SCI7_TXI7(void) __attribute__ ((interrupt));
void INT_Excep_SCI7_TEI7(void) __attribute__ ((interrupt));
void INT_Excep_SCI8_RXI8(void) __attribute__ ((interrupt));
void INT_Excep_SCI8_TXI8(void) __attribute__ ((interrupt));
void INT_Excep_SCI8_TEI8(void) __attribute__ ((interrupt));
void INT_Excep_SCI9_RXI9(void) __attribute__ ((interrupt));
void INT_Excep_SCI9_TXI9(void) __attribute__ ((interrupt));
void INT_Excep_SCI9_TEI9(void) __attribute__ ((interrupt));
void INT_Excep_SCI10_RXI10(void) __attribute__ ((interrupt));
void INT_Excep_SCI10_TXI10(void) __attribute__ ((interrupt));
void INT_Excep_SCI10_TEI10(void) __attribute__ ((interrupt));
void INT_Excep_SCI11_RXI11(void) __attribute__ ((interrupt));
void INT_Excep_SCI11_TXI11(void) __attribute__ ((interrupt));
void INT_Excep_SCI11_TEI11(void) __attribute__ ((interrupt));
void INT_Excep_SCI12_RXI12(void) __attribute__ ((interrupt));
void INT_Excep_SCI12_TXI12(void) __attribute__ ((interrupt));
void INT_Excep_SCI12_TEI12(void) __attribute__ ((interrupt));
void INT_Excep_IEB_IEBINT(void) __attribute__ ((interrupt));


